@@ -17,6 +17,7 @@ except ImportError:
     WINDOWS = True
     UNIX = False
 
+from copy import deepcopy
 from os import chdir
 from shlex import split as shlex_split
 from typing import List, Union
@@ -211,15 +212,24 @@ def interactive_loop(
                     command_sequences.rewind_to(index)
                     continue
 
-                if command[0] == "0":
+                command_lower = command[0].lower()
+
+                # Aliases are now fully unpacked. If the command sequences
+                # contain loops, execute in a subprocess unless this is just
+                # setting up an alias.
+                if not command_lower == "alias":
+                    if _exec_loop(
+                        speaker, command, command_sequences, use_local_speaker_list
+                    ):
+                        break
+
+                if command_lower == "0":
                     # Unset the active speaker
                     logging.info("Unset active speaker")
                     speaker_name = None
                     speaker = None
                     continue
 
-                command_lower = command[0].lower()
-
                 if command_lower.startswith("exit"):
                     logging.info("Exiting interactive mode")
                     _save_readline_history()
@@ -243,11 +253,6 @@ def interactive_loop(
                     _print_speaker_list(use_local_speaker_list=use_local_speaker_list)
                     continue
 
-                # if command_lower in ["wait", "wait_until", "wait_for"]:
-                #     logging.info("Processing a 'wait' action")
-                #     process_wait(command)
-                #     continue
-
                 if command_lower in ["version"]:
                     print()
                     version()
@@ -289,13 +294,6 @@ def interactive_loop(
                 except ValueError:
                     pass
 
-                # if command_lower == "rediscover":
-                #     if use_local_speaker_list:
-                #         print("Using cached speaker list: no discovery performed")
-                #     else:
-                #         speaker_cache().discover(reset=True)
-                #     continue
-
                 if command_lower == "rescan":
                     _rescan(use_local_speaker_list=use_local_speaker_list)
                     continue
@@ -309,7 +307,6 @@ def interactive_loop(
                 if command_lower == "exec":
                     if len(command) > 1:
                         _exec(command[1:])
-                        # print()
                     continue
 
                 if command_lower == "cd":
@@ -375,11 +372,6 @@ def interactive_loop(
                             print("Alias '{}' removed".format(alias_name))
                         else:
                             print("Alias '{}' not found".format(alias_name))
-                    if _loop_action_in_command_line(command_line):
-                        print(
-                            "Not permitted: cannot create alias containing 'loop' actions"
-                        )
-                        break
                     else:
                         # Have to collect the remaining sequences: they're all
                         # part of the alias. Reconstruction required.
@@ -408,12 +400,6 @@ def interactive_loop(
                     )
                     continue
 
-                # Check for loop statements; run in a subprocess
-                if _exec_loop_in_subprocess(
-                    speaker, command_line, use_local_speaker_list
-                ):
-                    break
-
                 # Command processing
                 try:
                     args = command
@@ -562,7 +548,7 @@ def _show_actions():
     print("==================================")
     print()
     list_actions(
-        include_loop_actions=False,
+        include_loop_actions=True,
         include_wait_actions=True,
         include_track_follow_actions=True,
     )
@@ -579,7 +565,7 @@ def _set_actions_and_commands_list(use_local_speaker_list=False):
         [
             action + " "
             for action in get_actions(
-                include_loop_actions=False,
+                include_loop_actions=True,
                 include_wait_actions=True,
                 include_track_follow_actions=True,
             )
@@ -888,21 +874,55 @@ def _exec_command_line(command_line: str) -> None:
     set_suspend_sighandling(suspend=False)
 
 
-def _exec_loop_in_subprocess(
-    speaker: Union[SoCo, None], command_line: str, use_local: bool
+def _loop_in_command_sequences(command_sequences: RewindableList) -> bool:
+    """Is there a loop statement in any of the command sequences?"""
+    for sequence in command_sequences:
+        if any(
+            loop_action in sequence
+            for loop_action in ["loop", "loop_until", "loop_for"]
+        ):
+            logging.info("'loop' action found in command sequences")
+            return True
+    return False
+
+
+def _exec_loop(
+    speaker: Union[SoCo, None],
+    current_command: list,
+    remaining_sequences: RewindableList,
+    use_local: bool,
 ) -> bool:
-    """If there's a loop statement, run the command in a subprocess.
+    """If there's a loop statement, run the actions in a subprocess.
 
     Args:
         speaker (SoCo, None): The speaker to which the command is targeted, or
             None if the speaker is in the command line.
-        command_line (str): The complete command line.
+        current_command (list): The current command sequence
+        remaining_sequences (RewindableList): The remaining list of command sequences
         use_local (bool): use the local speaker list.
 
     Returns:
         bool: True if there's a loop statement, False otherwise.
     """
-    if _loop_action_in_command_line(command_line):
+
+    # Reassemble the complete command sequence list
+    command_sequences = deepcopy(remaining_sequences)
+    command_sequences.insert(0, current_command)
+
+    if _loop_in_command_sequences(command_sequences):
+        command_line = ""
+        first = True
+        while True:
+            try:
+                sequence = command_sequences.pop_next()
+                if not first:
+                    command_line += " : "
+                command_line += " ".join(sequence)
+                if first:
+                    first = False
+            except IndexError:
+                break
+
         global LOG_SETTING
         sonos_command = "sonos " + LOG_SETTING + " "
         if speaker is not None:
@@ -933,17 +953,3 @@ def _exec_loop_in_subprocess(
         return True
 
     return False
-
-
-def _loop_action_in_command_line(command_line: str) -> bool:
-    """Does the command line contain a loop statement
-
-    Args:
-        command_line (str): The command line to test.
-
-    Returns:
-        bool: True if there's a loop in this command line.
-    """
-    return any(
-        word in command_line.split() for word in ["loop", "loop_until", "loop_for"]
-    )
